@@ -341,7 +341,7 @@ dump_dic(lexicon_t *entries, FILE *output[], da_build_t *builder)
 	    lex.con_tbl = con_tbl + i - 1;
 	    /*	    strcpy(entries[0].headword + stem_len,
 		    Cha_form[lex.inf_type][i].gobi); */
-	    if (!entries[0].reading[0])
+	    if (!entries[0].reading)
 		continue;
 	    lex_index = dump_lex(&lex, tmpfile);
 	    hira = katakana2hiragana(entries[0].reading);
